@@ -29,14 +29,12 @@ import static org.mockito.Mockito.mockConstruction;
 import static org.mockito.Mockito.when;
 
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
 import io.fabric8.kubernetes.api.model.ObjectMeta;
 import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
-import org.apache.commons.lang3.RandomStringUtils;
 import org.junit.jupiter.api.Test;
 import org.mockito.MockedConstruction;
 
@@ -45,6 +43,7 @@ import org.apache.spark.deploy.k8s.submit.JavaMainAppResource;
 import org.apache.spark.deploy.k8s.submit.PythonMainAppResource;
 import org.apache.spark.deploy.k8s.submit.RMainAppResource;
 import org.apache.spark.k8s.operator.spec.ApplicationSpec;
+import org.apache.spark.k8s.operator.spec.RuntimeVersions;
 import org.apache.spark.k8s.operator.status.ApplicationAttemptSummary;
 import org.apache.spark.k8s.operator.status.ApplicationStatus;
 import org.apache.spark.k8s.operator.status.AttemptInfo;
@@ -77,10 +76,10 @@ class SparkAppSubmissionWorkerTest {
 
       SparkAppSubmissionWorker submissionWorker = new SparkAppSubmissionWorker();
       SparkAppDriverConf conf = submissionWorker.buildDriverConf(mockApp, overrides);
-      assertEquals(6, constructorArgs.get(conf).size());
+      assertEquals(7, constructorArgs.get(conf).size());
 
       // validate SparkConf with override
-      assertTrue(constructorArgs.get(conf).get(0) instanceof SparkConf);
+      assertInstanceOf(SparkConf.class, constructorArgs.get(conf).get(0));
       SparkConf createdConf = (SparkConf) constructorArgs.get(conf).get(0);
       assertEquals("bar", createdConf.get("foo"));
       assertEquals("5", createdConf.get("spark.executor.instances"));
@@ -91,14 +90,14 @@ class SparkAppSubmissionWorkerTest {
           "namespace from CR takes highest precedence");
 
       // validate main resources
-      assertTrue(constructorArgs.get(conf).get(2) instanceof JavaMainAppResource);
-      JavaMainAppResource mainResource = (JavaMainAppResource) constructorArgs.get(conf).get(2);
+      assertInstanceOf(JavaMainAppResource.class, constructorArgs.get(conf).get(3));
+      JavaMainAppResource mainResource = (JavaMainAppResource) constructorArgs.get(conf).get(3);
       assertTrue(mainResource.primaryResource().isEmpty());
 
-      assertEquals("foo-class", constructorArgs.get(conf).get(3));
+      assertEquals("foo-class", constructorArgs.get(conf).get(4));
 
-      assertTrue(constructorArgs.get(conf).get(4) instanceof String[]);
-      String[] capturedArgs = (String[]) constructorArgs.get(conf).get(4);
+      assertInstanceOf(String[].class, constructorArgs.get(conf).get(5));
+      String[] capturedArgs = (String[]) constructorArgs.get(conf).get(5);
       assertEquals(2, capturedArgs.length);
       assertEquals("a", capturedArgs[0]);
       assertEquals("b", capturedArgs[1]);
@@ -120,16 +119,44 @@ class SparkAppSubmissionWorkerTest {
       when(mockSpec.getPyFiles()).thenReturn("foo");
 
       SparkAppSubmissionWorker submissionWorker = new SparkAppSubmissionWorker();
-      SparkAppDriverConf conf = submissionWorker.buildDriverConf(mockApp, Collections.emptyMap());
-      assertEquals(6, constructorArgs.get(conf).size());
+      SparkAppDriverConf conf = submissionWorker.buildDriverConf(mockApp, Map.of());
+      assertEquals(7, constructorArgs.get(conf).size());
 
       // validate main resources
-      assertInstanceOf(PythonMainAppResource.class, constructorArgs.get(conf).get(2));
-      PythonMainAppResource mainResource = (PythonMainAppResource) constructorArgs.get(conf).get(2);
+      assertInstanceOf(PythonMainAppResource.class, constructorArgs.get(conf).get(3));
+      PythonMainAppResource mainResource = (PythonMainAppResource) constructorArgs.get(conf).get(3);
       assertEquals("foo", mainResource.primaryResource());
     }
   }
 
+  @Test
+  void handlePyFiles() {
+    Map<SparkAppDriverConf, List<Object>> constructorArgs = new HashMap<>();
+    try (MockedConstruction<SparkAppDriverConf> mocked =
+        mockConstruction(
+            SparkAppDriverConf.class,
+            (mock, context) -> constructorArgs.put(mock, new ArrayList<>(context.arguments())))) {
+      SparkApplication mockApp = mock(SparkApplication.class);
+      ApplicationSpec mockSpec = mock(ApplicationSpec.class);
+      ObjectMeta appMeta = new ObjectMetaBuilder().withName("app1").withNamespace("ns1").build();
+      when(mockApp.getSpec()).thenReturn(mockSpec);
+      when(mockApp.getMetadata()).thenReturn(appMeta);
+      when(mockSpec.getMainClass()).thenReturn("org.apache.spark.deploy.PythonRunner");
+      when(mockSpec.getPyFiles()).thenReturn("main.py,lib.py");
+
+      SparkAppSubmissionWorker submissionWorker = new SparkAppSubmissionWorker();
+      SparkAppDriverConf conf = submissionWorker.buildDriverConf(mockApp, Map.of());
+      assertEquals(7, constructorArgs.get(conf).size());
+      assertEquals(
+          "lib.py", ((SparkConf) constructorArgs.get(conf).get(0)).get("spark.submit.pyFiles"));
+
+      // validate main resources
+      assertInstanceOf(PythonMainAppResource.class, constructorArgs.get(conf).get(3));
+      PythonMainAppResource mainResource = (PythonMainAppResource) constructorArgs.get(conf).get(3);
+      assertEquals("main.py", mainResource.primaryResource());
+    }
+  }
+
   @Test
   void buildDriverConfForRApp() {
     Map<SparkAppDriverConf, List<Object>> constructorArgs = new HashMap<>();
@@ -145,12 +172,12 @@ class SparkAppSubmissionWorkerTest {
       when(mockSpec.getSparkRFiles()).thenReturn("foo");
 
       SparkAppSubmissionWorker submissionWorker = new SparkAppSubmissionWorker();
-      SparkAppDriverConf conf = submissionWorker.buildDriverConf(mockApp, Collections.emptyMap());
-      assertEquals(6, constructorArgs.get(conf).size());
+      SparkAppDriverConf conf = submissionWorker.buildDriverConf(mockApp, Map.of());
+      assertEquals(7, constructorArgs.get(conf).size());
 
       // validate main resources
-      assertInstanceOf(RMainAppResource.class, constructorArgs.get(conf).get(2));
-      RMainAppResource mainResource = (RMainAppResource) constructorArgs.get(conf).get(2);
+      assertInstanceOf(RMainAppResource.class, constructorArgs.get(conf).get(3));
+      RMainAppResource mainResource = (RMainAppResource) constructorArgs.get(conf).get(3);
       assertEquals("foo", mainResource.primaryResource());
     }
   }
@@ -209,8 +236,8 @@ class SparkAppSubmissionWorkerTest {
 
   @Test
   void generatedSparkAppIdShouldComplyLengthLimit() {
-    String namespaceName = RandomStringUtils.randomAlphabetic(253);
-    String appName = RandomStringUtils.randomAlphabetic(253);
+    String namespaceName = "n".repeat(253);
+    String appName = "a".repeat(253);
 
     SparkApplication mockApp = mock(SparkApplication.class);
     ObjectMeta appMeta =
@@ -232,7 +259,32 @@ class SparkAppSubmissionWorkerTest {
     when(mockApp.getMetadata()).thenReturn(appMeta);
 
     SparkAppSubmissionWorker submissionWorker = new SparkAppSubmissionWorker();
-    SparkAppDriverConf conf = submissionWorker.buildDriverConf(mockApp, Collections.emptyMap());
-    assertEquals(conf.appId(), "foo");
+    SparkAppDriverConf conf = submissionWorker.buildDriverConf(mockApp, Map.of());
+    assertEquals("foo", conf.appId());
+  }
+
+  @Test
+  void supportSparkVersionPlaceHolder() {
+    SparkApplication mockApp = mock(SparkApplication.class);
+    ApplicationSpec mockSpec = mock(ApplicationSpec.class);
+    RuntimeVersions mockRuntimeVersions = mock(RuntimeVersions.class);
+    Map<String, String> appProps = new HashMap<>();
+    appProps.put("spark.kubernetes.container.image", "apache/spark:{{SPARK_VERSION}}");
+    appProps.put("spark.kubernetes.driver.container.image", "apache/spark:{{SPARK_VERSION}}");
+    appProps.put("spark.kubernetes.executor.container.image", "apache/spark:{{SPARK_VERSION}}");
+    appProps.put("spark.kubernetes.key", "apache/spark:{{SPARK_VERSION}}");
+    ObjectMeta appMeta = new ObjectMetaBuilder().withName("app1").withNamespace("ns1").build();
+    when(mockSpec.getSparkConf()).thenReturn(appProps);
+    when(mockApp.getSpec()).thenReturn(mockSpec);
+    when(mockApp.getMetadata()).thenReturn(appMeta);
+    when(mockSpec.getRuntimeVersions()).thenReturn(mockRuntimeVersions);
+    when(mockRuntimeVersions.getSparkVersion()).thenReturn("dev");
+
+    SparkAppSubmissionWorker submissionWorker = new SparkAppSubmissionWorker();
+    SparkAppDriverConf conf = submissionWorker.buildDriverConf(mockApp, Map.of());
+    assertEquals("apache/spark:dev", conf.get("spark.kubernetes.container.image"));
+    assertEquals("apache/spark:dev", conf.get("spark.kubernetes.driver.container.image"));
+    assertEquals("apache/spark:dev", conf.get("spark.kubernetes.executor.container.image"));
+    assertEquals("apache/spark:{{SPARK_VERSION}}", conf.get("spark.kubernetes.key"));
   }
 }
